aboutsummaryrefslogtreecommitdiff
path: root/lib/CodeGen/CodeGenFunction.h
diff options
context:
space:
mode:
authorJohn McCall <rjmccall@apple.com>2012-04-06 18:21:03 +0000
committerJohn McCall <rjmccall@apple.com>2012-04-06 18:21:03 +0000
commit3f88f686e32949ffe02ccb551f482f9cf810358b (patch)
treea43f789145ba3e2a44ebe704d1deab7d3bef3ba9 /lib/CodeGen/CodeGenFunction.h
parent7f39d51d9c8f551fd09c1feee3d8033f5702b2cb (diff)
Rename GenerateCXXGlobalDtorFunc to GenerateCXXGlobalDtorsFunc.
git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@154190 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/CodeGen/CodeGenFunction.h')
-rw-r--r--lib/CodeGen/CodeGenFunction.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/CodeGen/CodeGenFunction.h b/lib/CodeGen/CodeGenFunction.h
index 85cbd143d8..bcc2c7bc15 100644
--- a/lib/CodeGen/CodeGenFunction.h
+++ b/lib/CodeGen/CodeGenFunction.h
@@ -2429,11 +2429,11 @@ public:
llvm::Constant **Decls,
unsigned NumDecls);
/// GenerateCXXGlobalDtorFunc - Generates code for destroying global
/// variables.
- void GenerateCXXGlobalDtorFunc(llvm::Function *Fn,
- const std::vector<std::pair<llvm::WeakVH,
- llvm::Constant*> > &DtorsAndObjects);
+ void GenerateCXXGlobalDtorsFunc(llvm::Function *Fn,
+ const std::vector<std::pair<llvm::WeakVH,
+ llvm::Constant*> > &DtorsAndObjects);
void GenerateCXXGlobalVarDeclInitFunc(llvm::Function *Fn,
const VarDecl *D,
@@ -2429,11 +2429,11 @@ public:
llvm::Constant **Decls,
unsigned NumDecls);
- /// GenerateCXXGlobalDtorFunc - Generates code for destroying global
+ /// GenerateCXXGlobalDtorsFunc - Generates code for destroying global
/// variables.